@@ -236,21 +236,12 @@ If optional argument SAFE is nil, overwrite previous definitions."
   (let ((files (if file
 		   (setq riece-variables-file file
 			 riece-variables-files (list file))
-		 riece-variables-files))
-	(variables riece-saved-forms))
+		 riece-variables-files)))
     (while files
       (condition-case nil
 	  (load (expand-file-name (car files)))
 	(file-error nil))
-      (setq files (cdr files)))
-    (while variables
-      (if (fboundp 'custom-reevaluate-setting)
-	  (custom-reevaluate-setting (car variables))
-	(funcall (or (get (car variables) 'custom-set) 'set-default)
-		 (car variables)
-		 (eval (car (or (get (car variables) 'saved-value)
-				(get (car variables) 'standard-value))))))
-      (setq variables (cdr variables)))))
+      (setq files (cdr files)))))
 
 (defvar print-quoted)
 (defvar print-escape-multibyte)
@@ -266,14 +257,12 @@ If optional argument SAFE is nil, overwrite previous definitions."
 	  print-level
 	  print-length
 	  (variables riece-saved-forms))
-      (insert "(custom-set-variables\n")
       (while variables
-	(insert " '")
-	(prin1 `(,(car variables) ',(symbol-value (car variables)))
+	(prin1 `(setq ,(car variables)
+		      ',(symbol-value (car variables)))
 	       (current-buffer))
 	(insert "\n")
-	(setq variables (cdr variables)))
-      (insert ")")))
+	(setq variables (cdr variables)))))
   (message (riece-mcat "Saving %s...done") riece-saved-variables-file)
   (setq riece-save-variables-are-dirty nil))
 
